#################################################################
Active Technologies AWG-401x 1.2GS/s Arbitrary Waveform Generator
#################################################################

.. autoclass:: pymeasure.instruments.activetechnologies.AWG401x_AFG
    :members:
    :show-inheritance:

.. autoclass:: pymeasure.instruments.activetechnologies.AWG401x_AWG
    :members:
    :show-inheritance:

.. autoclass:: pymeasure.instruments.activetechnologies.AWG401x.ChannelAFG
    :members:
    :show-inheritance:
